@@ -29,6 +29,7 @@ GetOptions (\%options,
                pdf
                zip
                ttdir=s
+               fontspec=s
                webfontsdir=s
                output-templates
                log=s
@@ -59,7 +60,7 @@ if ($options{version}) {
 
 =head1 NAME
 
-muse-compile.pl -- format your muse document using Text::Amuse
+muse-compile.pl - format your muse document using Text::Amuse
 
 =head1 SYNOPSIS
 
@@ -124,10 +125,21 @@ As above, but on Letter paper.
 The directory with the templates. Optional and somehow discouraged for
 normal usage.
 
+=item --fontspec fontspec.json
+
+A specification JSON file with the list of fonts. This permits you to
+use arbitrary fonts. To create one with the default list, you can use
+the command L<muse-create-font-file.pl>, generate one, then pass it to
+this script together with --extra mainfont="Font Name".
+
 =item --webfontsdir
 
 For EPUB output, embed the fonts in that directory.
 
+This option is DEPRECATED now. The preferred way is to pass a fontspec
+file and pass --extra mainfont "Font Name", which ensure the
+consistency between the EPUB and the PDF.
+
 In this directory the program expects to find 4 fonts, a regular, an
 italic, a bold and a bold italic one. Given that the names are
 arbitrary, we need an hint. For this you have to provide a file, in
